btESBL_model3posterior: Data: Posterior of fitted carriage model (seperate...

btESBL_model3posteriorR Documentation

Data: Posterior of fitted carriage model (seperate ceftriaxone effect)

Description

Posterior of fitted longitudinal model of ESBL colonisation incorporating an effect of antimicrobial exposure that exponentially decays following cessation of exposure, with ceftriaxone effect seperate from all otehr antimicrobials

Usage

btESBL_model3posterior

Format

An S4 stanfit object (package "rstan") including model log-likelihood

Details

See manuscript for interpretation of parameters etc.


joelewis101/blantyreESBL documentation built on Nov. 1, 2023, 1:43 p.m.